"""Top-level package for model_reduction."""

__author__ = """Meghna Sarah Thomas"""
__email__ = 'meghnathomas@utexas.edu'
__version__ = '0.1.5'


from magnets import utils
from magnets import preprocessing
from magnets import reduction
